@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20110831';
+our $VERSION = '0.20110930';
 
-# Table last modified: 2011-08-31
+# Table last modified: 2011-09-30
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[02]1|88)|612))',
     '002' => '(?:850[1-4])',
@@ -44,7 +44,7 @@ our %ZIP_TABLE = (
     '038' => '(?:(?:3(?:19[2-6]|39[2-4]|[68]92|595)|85(?:[08]5|60|5[05])|0(?:19[24]|292)|2(?:79[23]|892)|1392))',
     '039' => '(?:(?:2(?:2(?:9[23]|8[0-35-79])|59[2-578]|39[23]|49[23]|79[23]|192|696)|0(?:19[58]|[28]92|595)|11(?:8[015]|9[237])|4(?:29[23]|495|692)|3393))',
     '040' => '(?:8(?:5(?:77|3[03]|4[13]|5[0-258]|2[02]|8[0158]|0[12]|6[0167]|1[0-2])|6(?:55|4[02]|7[07]|[68][068]|3[12]|0[1-359]|1[016])|7(?:[12][07])))',
-    '041' => '(?:(?:8(?:5(?:01|33|40|77|2[23]|1[015]|8[89]|6[07]|5[1-8])|6(?:[23]3|48|55|80|1[01])|711)|1(?:19[2-6]|49[6-8]|[36]92)))',
+    '041' => '(?:(?:8(?:5(?:01|33|40|77|2[23]|8[89]|1[0-25]|6[07]|5[1-8])|6(?:[23]3|48|55|80|1[01])|711)|1(?:19[2-6]|49[6-8]|[36]92)))',
     '042' => '(?:8(?:5(?:[01]1|67|8[58]|5[05])|6(?:39|42|78)))',
     '043' => '(?:(?:8(?:5(?:58|60)|6(?:09|51))|0[45]95|1498))',
     '044' => '(?:(?:85(?:44|88)|029[256]))',
@@ -103,12 +103,12 @@ our %ZIP_TABLE = (
     '097' => '(?:8(?:5(?:10|85|5[58]|2[57])|6(?:[03]9|[68]6)))',
     '098' => '(?:(?:5(?:[78]92|298|595)|(?:28|62|0[13])92|1(?:69[23]|792)|339[23568]))',
     '099' => '(?:(?:2(?:19[2-8]|49[235]|392)|1(?:49[2568]|19[78]|595)|3(?:29[23]|69[78])|4(?:19[256]|492)|(?:56|65)92|049[245]))',
-    '100' => '(?:(?:8(?:9(?:4[015]|8[0-35-79]|6[0-25-9]|7[0-2457-9]|2[0-24-79]|9[46]|3[0137]|1[02-9]|0[1-579]|5[0-3569])|1(?:3[01589]|8[0-25-9]|6\d|0[2358]|4[0149]|5[016-8]|7[1-37]|1[01357-9]|2[0-3568])|6(?:55|86|2[019]|1[057]|3[0-29]|7[067]|6[3568]|0[268]|4[049])|3(?:66|70|5[015]|0[2378]|4[158]|2[1245]|3[138]|1[01]|8[038])|2(?:46|70|6[02578]|2[78]|8[2358]|0[13]|1[014-69]|3[2-4])|5(?:11|43|5[058]|2[02]|6[07]|8[58]|7[57]|0[35-7])|4(?:02|56|1[015]|2[0147]|3[09]|4[048]|8[48])|0(?:19|66|7[07-9]|8[68]|5[01])|79[158])|6(?:1(?:62|7[0-578]|5[0-2])|2(?:55|77|6[02])|0(?:66|80)|75[1-6])|149[28]|3131))',
+    '100' => '(?:(?:8(?:9(?:4[015]|8[0-35-79]|6[0-25-9]|7[0-2457-9]|2[0-24-79]|9[46]|3[0137]|1[02-9]|0[1-579]|5[0-3569])|1(?:3[01589]|6\d|0[2358]|4[0149]|5[016-8]|8[0-26-9]|7[1-37]|1[01357-9]|2[0-3568])|6(?:55|86|2[019]|1[057]|3[0-29]|7[067]|6[3568]|0[268]|4[049])|3(?:66|70|5[015]|0[2378]|4[158]|2[1245]|3[138]|1[01]|8[038])|2(?:46|70|6[02578]|2[78]|8[2358]|0[13]|1[014-69]|3[2-4])|5(?:11|4[03]|5[058]|2[02]|6[07]|8[58]|7[57]|0[35-7])|4(?:02|56|1[015]|2[0147]|3[09]|4[048]|8[48])|0(?:19|66|7[07-9]|8[68]|5[01])|79[158])|6(?:1(?:62|7[0-578]|5[0-2])|2(?:55|77|6[02])|0(?:66|80)|75[1-6])|149[28]|3131))',
     '101' => '(?:8(?:3(?:3[135]|0[1257-9]|8[01358]|6[02356]|7[0158]|5[0-689]|2[1-8]|1[013-7]|4[56])|5(?:6[0-2568]|5[289]|4[2-5]|8[1568]|7[6-9]|0[1-46-9]|3[0-5]|1[0-24-69]|2[0-3568])|4(?:7[05-7]|8[13]|0[57-9]|3[0379]|4[13-9]|6[04-9]|5[0-46-9]|2[125]|1[0-25689])|6(?:8[28]|0[5-79]|6[2578]|3[0346-8]|5[14-6]|4[1-3568]|1[0-479]|7[026]|2[0-24-9])|9(?:[019]1|35|50|7[0-37]|4[16]|8[036])|7(?:0[137]|1[0-25-8])|0(?:11|50|77|0[12])|20[1-4]|101))',
     '102' => '(?:8(?:4(?:5[0-2569]|8[13489]|6[0-24-68]|4[057]|2[014679]|0[125-7]|1[014579]|7[0478]|3[0-3578])|1(?:1[0-278]|5[0-25]|3[0-289]|7[0-25-8]|8[0-24-8]|2[02358]|0[1-359]|4[0-24]|6[016])|6(?:3[0-3579]|4[245]|2[016-8]|8[0589]|7[17-9]|0[1-479]|1[0-47-9]|5[016]|6[06-8])|5(?:5[024-9]|2[0289]|6[079]|3[0139]|4[013]|8[0458]|1[01568]|7[013578]|0[2-68])|3(?:4[19]|1[0134]|3[1-356]|8[1-38]|7[0237]|5[035-7]|6[248]|0[1-359]|2[0-24])|2(?:88|5[015]|1[158]|7[257]|2[2568]|3[0-2468]|0[15]|6[0245]|4[016])|0(?:08|77|8[0-35]|1[125689])|79[58]))',
     '103' => '(?:8(?:2(?:0[1-6]|1[0-2478]|3[0-35-9]|6[0135]|4[0-35-8]|7[02358]|8[457]|2[124589]|5[0-25689])|4(?:7[0-3]|2[2-7]|0[1-57]|6[0-256]|3[0-57-9]|1[0-79]|8[01467]|5[016]|4[3489])|5(?:0[1-367]|4[2358]|8[4-689]|[12][0-25]|5[24-68]|3[013-8]|6[067]|7[0157])|3(?:7[03]|5[0-2458]|0[136-8]|8[0348]|2[01348]|4[15-7]|1[0137]|6[036]|3[01357-9])|6(?:7[05-7]|6[0568]|3[0-269]|8[0469]|5[0-36]|4[014])|0[01]1))',
     '104' => '(?:(?:8(?:1(?:2[2-589]|3[0-58]|0[124-689]|5[158]|8[0139]|1[124-8]|4[25]|6[1-8]|7[0-25-8])|4(?:1[01589]|2[0-2459]|4[03-578]|8[168]|0[1-8]|[67][068]|5[0156]|3[013-68])|5(?:1[028]|4[0468]|3[03589]|5[0134689]|7[02]|2[0138]|6[036-8]|0[1256]|8[014578])|3(?:6[015]|4[04]|1[0-3579]|2[01458]|5[167]|7[27]|3[02358]|8[038]|0[2-59])|2(?:4[03]|1[0-258]|3[38]|2[28]|0[568]|5[0-35-7]|7[07]|6[026]|8[0-24589])|6(?:50|6[0158]|8[05]|7[08])|0(?:55|77|1[01]|0[1347]))|6241))',
-    '105' => '(?:(?:8(?:4(?:3[24-79]|0[124578]|8[02-8]|1[0-24-689]|5[0-35-8]|2[0-247-9]|7[0-39]|4[014-9]|6[01457])|5(?:2[0-357-9]|1[0-2578]|8[0-2457-9]|5[02-8]|0[579]|7[4-9]|4[35689]|6[0378]|3[0457])|6(?:54|6[0568]|1[01348]|4[02]|7[078]|3[014]|8[05-9]|2[1346]|0[3468])|0(?:55|0[12578]|7[07]|8[58]|1[0-2])|3(?:01|22|33|1[0-3])|7(?:0[127]|1[1267]))|7444))',
+    '105' => '(?:(?:8(?:4(?:3[24-79]|0[124578]|8[02-8]|1[0-24-689]|5[0-35-8]|2[0247-9]|7[0-39]|4[014-9]|6[01457])|5(?:2[0-357-9]|1[0-2578]|8[0-2457-9]|5[02-8]|0[579]|7[4-9]|4[35689]|6[0378]|3[0457])|6(?:54|6[0568]|1[01348]|4[02]|7[078]|3[014]|8[05-9]|2[1346]|0[3468])|0(?:55|0[12578]|7[07]|8[58]|1[0-2])|3(?:01|22|33|1[0-3])|7(?:0[127]|1[1267]))|7444))',
     '106' => '(?:(?:8(?:5(?:08|4[134]|6[0-35-79]|7[136-8]|3[25]|1[458]|2[12]|5[0-35689]|8[0157-9])|6(?:77|6[158]|5[25]|1[168]|0[18]|2[0256]|8[15]|3[069]|4[0-24589])|0(?:[01]1|39)|7(?:11|97)|401)|6(?:1(?:61|88)|06[06])))',
     '107' => '(?:8(?:5(?:8[13589]|2[0-24578]|5[0-26-8]|4[356]|3[023]|0[258]|7[0579]|6[0357]|1[15])|6(?:42|8[06]|6[78]|2[023578]|1[15-79]|0[14]|7[46]|3[0-3689]|5[05])|4(?:20|34|56|77|0[134]|8[24]|6[067]|1[04679]|4[08])|3(?:55|4[028]|7[013]|3[1568]|2[0346]|8[08])|0(?:06|77)))',
     '108' => '(?:(?:8(?:5(?:7[01358]|3[02369]|6[124-8]|4[03-578]|5[0-35-9]|0[1-3569]|2[035]|1[0258]|8[013568])|3(?:3[13489]|1[137]|6[0168]|0[357]|7[0-37-9]|5[0158]|8[134689]|4[15]|2[0-35689])|4(?:0[347]|8[45]|6[67]|5[16]|7[478]|2[013-5]|3[029]|1[0-24-7]|4[48])|2(?:7[05-8]|4[128]|8[02]|0[1-38]|3[0-4]|5[05]|1[01]|2[0-28])|6(?:50|1[0-2568]|4[0-2468]|0[126-8]|3[235-8]|2[0-28])|0(?:[25]0|11|8[08]|7[01]|0[15])|7(?:23|1[03]|0[1-37])|117)|63(?:50|63)))',
@@ -131,16 +131,16 @@ our %ZIP_TABLE = (
     '133' => '(?:8(?:5(?:[01]1|8[05]|5[238])|70[46]))',
     '134' => '(?:8(?:6(?:22|78|86|[14][02]|0[1-39]|3[01])|5(?:[15]5|20|33|7[05-7]|8[568]|0[237])|702))',
     '135' => '(?:8(?:5(?:3[0-35]|5\d|7[03-57-9]|8[125-7]|6[035-7]|0[1458]|4[08]|2[1-358]|1[0-478])|4(?:22|4[0358]|0[24]|7[0137]|5[18]|8[0-2]|6[014]|1[15]|3[026])|6(?:02|41|86|2[0-25]|6[168]|3[0-29]|7[0178]|5[059]|1[146-9])|3(?:50|8[3-578]|7[025]|0[13]|2[02]|6[0236]|3[01]|1[0-28])|7(?:3[0-38]|2[0-3]|0[17]|1[0178])|11[0-4]))',
-    '136' => '(?:8(?:5(?:4[03]|1[2357]|3[13]|7[057]|5[058]|6[07]|8[0189]|0[1257]|2[1-35])|6(?:[68]6|3[057]|0[357]|7[05]|2[0267]|4[08]|1[125])|7(?:[23]3|11)|405|880|908))',
+    '136' => '(?:8(?:5(?:4[03]|1[2357]|3[13]|7[057]|5[058]|6[07]|8[0189]|0[1257]|2[1-35])|6(?:[68]6|3[057]|0[357]|7[0157]|2[0267]|4[08]|1[125])|7(?:[23]3|11)|405|880|908))',
     '137' => '(?:8(?:6(?:23|50|86)|08[18]|581))',
     '140' => '(?:8(?:5(?:[89]0|7[1-36]|4[0-37-9]|2[01359]|3[013689]|6[0367]|0[125-8]|5[0-28]|1[1256])|6(?:4[04]|0[17]|6[0168]|1[13-79]|7[0578]|2[13568]|8[078]|3[01479]|5[03568])|7(?:88|1[015-7]|2[12]|0[279])))',
-    '141' => '(?:8(?:6(?:3[0136-9]|2[01389]|4[0-36-8]|0[2-6]|7[0-36]|1[01568]|8[0136-8]|5[035-8]|6[024-68])|5(?:2[0-2569]|0[13-578]|4[045]|1[024579]|3[03-5]|5[05-79]|6[015-8]|7[1256]|8[02-68])|4(?:2[0-3]|1[1-9])|7(?:0[127]|1[05])|001))',
+    '141' => '(?:8(?:6(?:3[0137-9]|2[01389]|4[0-36-8]|0[2-6]|7[0-36]|1[01568]|8[0136-8]|5[035-8]|6[024-68])|5(?:2[0-2569]|0[13-578]|4[045]|1[024579]|3[03-5]|5[05-79]|6[015-8]|7[1256]|8[02-68])|4(?:2[0-3]|1[1-9])|7(?:0[127]|1[05])|001))',
     '142' => '(?:8(?:5(?:[01]1|22|33|40|67|5[058]|8[58])|6(?:11|39|66)))',
     '143' => '(?:(?:85(?:28|70|3[13589]|8[05]|6[04578]|0[4-8]|4[014]|5[0258]|1[145])|6501))',
     '144' => '(?:8(?:5(?:25|44|5[015]|3[0-356]|7[057]|1[01356]|8[08]|0[56])|6(?:02|35|2[1-3]|5[056]|7[78]|1[014]|6[01])))',
     '145' => '(?:85(?:[23]3|01|58|66|1[15]))',
     '146' => '(?:8(?:5(?:[03]1|22|67|8[058]|7[67]|1[0-2]|5[15]|4[034])|6(?:[03]1|10|2[03]|5[056]|7[78]|6[68])))',
-    '150' => '(?:8(?:3(?:19|4[03]|7[37]|8[3-5]|2[24-8]|0[1367]|5[05]|6[036]|3[038])|5(?:45|3[03]|0[23578]|8[5-7]|2[25]|1[124-7]|6[379]|5[05]|7[57])|4(?:12|36|0[289]|8[28]|5[15]|4[08])|9(?:02|11|40|55|2[35]|3[258])|0(?:[08]1|1[059])|6(?:88|7[237])))',
+    '150' => '(?:8(?:5(?:45|3[03]|0[23578]|8[5-7]|2[25]|1[124-7]|6[379]|5[05]|7[57])|3(?:19|4[03]|7[37]|8[45]|2[24-8]|0[1367]|5[05]|6[036]|3[038])|4(?:12|36|0[289]|8[28]|5[15]|4[08])|9(?:02|11|40|55|2[35]|3[258])|0(?:[08]1|1[059])|6(?:88|7[237])))',
     '151' => '(?:8(?:5(?:3\d|8[3-7]|2[1-589]|1[016-9]|6[1-35-9]|4[0-57-9]|5[24589]|7[0-46-8]|9[01]|0[2-579])|6(?:00|7[1-7])|40[14]))',
     '152' => '(?:8(?:5(?:61|4[149]|2[0-257]|0[36-8]|7[08]|1[01]|5[0-28]|3[1-35])|9(?:1[03]|0[24579])|6[02]1))',
     '153' => '(?:8(?:5(?:6[05-7]|2[0-356]|5[0-68]|4[0135]|8[0-25-79]|3[0169]|7[01378]|1[02568]|0[1-689])|6(?:01|20|8[78]|4[01458]|7[07]|6[025689]|5[02-57]|3[013568])|9(?:1[134]|0[246]|2[2357]|3[034679])))',
@@ -278,7 +278,7 @@ our %ZIP_TABLE = (
     '302' => '(?:(?:85(?:85|0[12])|019[28]))',
     '303' => '(?:850[13])',
     '304' => '(?:8[56]01)',
-    '305' => '(?:8(?:5(?:55|6[1-9]|0[146]|8[58]|2[01]|1[56])|6(?:42|8[67]|0[12])))',
+    '305' => '(?:8(?:5(?:55|6[1-9]|0[146]|8[58]|2[01]|1[56])|6(?:42|0[124]|8[67])))',
     '306' => '(?:(?:0(?:49[2357]|[36]92|595)|86(?:01|86)))',
     '307' => '(?:8(?:50[12]|601))',
     '308' => '(?:(?:8(?:5(?:40|2[1-4]|1[0-3])|6(?:[03]8|16))|019[34]))',
@@ -291,9 +291,9 @@ our %ZIP_TABLE = (
     '315' => '(?:(?:8(?:5(?:22|85|1[12])|640)|0195))',
     '316' => '(?:85(?:11|33|0[12]))',
     '317' => '(?:8(?:5(?:11|55)|60[12]))',
-    '318' => '(?:8511)',
+    '318' => '(?:85[01]1)',
     '319' => '(?:(?:1(?:1(?:9[24-6]|8[48])|29[235]|59[23]|393)|0(?:29[2-5]|39[3-57]|19[28])|2692|3595))',
-    '320' => '(?:8(?:5(?:3[0-38]|6[0467]|8[058]|4[013]|5[0158]|7[07]|0[1-3578]|2[1-358]|1[0-2457])|6(?:20|55|68|1[018]|0[17]|8[068])))',
+    '320' => '(?:8(?:5(?:5[015]|3[0-38]|6[0467]|8[058]|4[013]|7[07]|0[1-3578]|2[1-358]|1[0-2457])|6(?:20|55|68|1[018]|0[17]|8[068])))',
     '321' => '(?:(?:3(?:29[235-8]|49[378]|39[25]|59[58])|0(?:29[2358]|19[458]|59[235]|692)|2(?:59[23568]|49[23]|792)|1(?:29[27]|49[23]|692)|4(?:39[23568]|29[235])|85(?:[58]5|0[25])))',
     '322' => '(?:(?:8(?:5(?:11|0[1-3]|8[58]|5[05])|6(?:66|88|0[13]))|0(?:393|692)))',
     '323' => '(?:(?:8(?:5(?:11|58|67|8[56])|6(?:[01]1|78|86))|[01]192))',
@@ -428,14 +428,14 @@ our %ZIP_TABLE = (
     '454' => '(?:8(?:5(?:3[03]|2[0-24-79]|5[058]|1[124-9]|6[05]|0[1-689])|651))',
     '455' => '(?:8(?:6(?:[07]1|[46]8|2[06]|3[09])|5(?:[1458]5|21|30|0[15])))',
     '456' => '(?:8(?:5(?:23|30|6[07]|1[16]|8[0578]|0[12]|5[56])|6(?:20|0[12]|1[0-2]|[68][68])|7(?:11|39|63)))',
-    '457' => '(?:8(?:5(?:[48]5|3[0-35]|[05][158]|2[02]|1[0-25]|7[07]|6[067])|711))',
+    '457' => '(?:8(?:5(?:[48]5|3[0-35]|[05][158]|2[02]|1[0-25]|7[07]|6[067])|71[12]))',
     '458' => '(?:85(?:30|55|[18][015]|0[1258]|2[0-25]|7[01]))',
     '459' => '(?:85(?:11|22|40))',
     '460' => '(?:8(?:6(?:90|7[0-2489]|8[1-9]|6[035-9]|0[1-3689]|3[0-35-8]|5[0135-7]|2[013568]|1[013-9])|4(?:7[02357]|0[1-35-8]|1[125-7]|8[1-58]|5[0156]|2[0256]|9[01]|3[0-69]|6[0-28]|4[014578])|5(?:5[01589]|[23][0-58]|8[05-8]|1[0-68]|4[0135]|7[04578]|0[13-9]|6[06-8])|3(?:02|6[06]|2[015]|5[018]|3[0138]|8[038]|1[0-24589])|7(?:20|65|91|0[1-46-8]|1[18])|20[1-4]))',
     '461' => '(?:8(?:5(?:60|8[0-2568]|2[025]|5[058]|3[0-29]|0[13-8]|7[57]|4[01]|1[125])|6(?:66|80|4[015]|3[019]|0[2358]|5[01458]|2[016]|1[024]|7[0-3568])|7(?:0[36-8]|2[159]|9[58]|1[0457])))',
     '462' => '(?:8(?:5(?:2[23]|4[03]|7[5-7]|5[158]|0[189]|3[05]|1[129]|8[08])|666))',
     '463' => '(?:85(?:[18]0|5[057]|2[128]|6[0157]|7[157]|0[1-35]|3[03568]|4[013578]))',
-    '464' => '(?:8(?:5(?:85|5[058]|2[0-25]|4[035-7]|1[12]|6[0167]|3[01369]|7[017])|6(?:[278]1|[06][1-3]|4[134]|3[1-357]|5[0-4]|1[0135-7])|710))',
+    '464' => '(?:8(?:5(?:85|5[058]|2[0-25]|4[035-7]|1[12]|6[0167]|3[01369]|7[017])|6(?:[278]1|0[1-3]|4[134]|3[1-357]|5[0-4]|6[12]|1[0135-7])|710))',
     '465' => '(?:8(?:5(?:20|6[05-7]|5[0-258]|0[15-8]|1[0156])|6(?:51|68|70|1[0-2]|2[026])))',
     '466' => '(?:8(?:5(?:40|3[39]|6[057]|2[25]|8[058]|1[0-25]|5[0458]|0[125-8])|6(?:73|6[06]|5[05-7]|3[035])|7(?:11|0[17])))',
     '467' => '(?:8(?:5(?:01|6[1-367]|7[17]|3[013]|8[0158]|2[0-25]|5[58]|1[01])|6(?:51|86|2[26]|1[015]|0[1-3]|3[039])))',
@@ -450,7 +450,7 @@ our %ZIP_TABLE = (
     '476' => '(?:8(?:5(?:[67]7|33|0[13]|8[58]|1[01])|6(?:[68]6|01)))',
     '477' => '(?:85(?:21|38))',
     '478' => '(?:8(?:5(?:55|0[1-5])|6(?:01|4[01])))',
-    '479' => '(?:8(?:5(?:01|55|77|8[5-9]|1[018])|7(?:87|0[1-8]|1[12])|6(?:01|10|23|68|86)))',
+    '479' => '(?:8(?:5(?:01|55|77|8[5-9]|1[018])|7(?:87|0[1-8]|1[12])|6(?:01|10|23|68)))',
     '480' => '(?:(?:0(?:2(?:8[128]|9[1246])|19[23578]|39[235])|1(?:1(?:8[89]|9[2-8])|298)))',
     '481' => '(?:8(?:5(?:26|88|4[03]|5[058]|1[0135]|0[1-58]|3[1359])|6(?:[08]1|15|78)))',
     '482' => '(?:8(?:5(?:01|30|55|1[01])|6(?:86|5[12])))',
@@ -510,7 +510,7 @@ our %ZIP_TABLE = (
     '538' => '(?:8(?:5(?:[58]5|01|10)|6(?:[68]6|55)))',
     '539' => '(?:8794)',
     '540' => '(?:(?:8(?:5(?:66|5[01589]|0[158]|3[03-5]|7[01578]|4[014]|2[267]|1[0-2579]|8[14-8])|6(?:20|8[69]|4[25]|3[09]|0[2-8]|7[078]|6[08]|1[01])|795)|6255))',
-    '541' => '(?:(?:85(?:2[013-689]|5[0346-9]|3[0457-9]|4[0-35-9]|1[124-9]|6[3568]|8[13-79]|7[15-9]|0[1-689])|6666))',
+    '541' => '(?:(?:85(?:5[01346-9]|2[013-689]|3[0457-9]|4[0-35-9]|1[124-9]|6[3568]|8[13-79]|7[15-9]|0[1-689])|6666))',
     '542' => '(?:8(?:5(?:33|42|77|0[1-4]|8[0568]|6[67]|2[235]|5[0458]|1[01])|6(?:54|60|8[68])|745))',
     '543' => '(?:8(?:5(?:43|[58][58]|0[12])|6(?:01|66|8[68])))',
     '544' => '(?:8(?:5(?:01|55)|666))',
@@ -583,7 +583,7 @@ our %ZIP_TABLE = (
     '617' => '(?:8(?:5(?:[01]1|[23]0|66|5[015]|8[58])|66[56]))',
     '618' => '(?:85(?:[28]5|67|70|0[13]|5[58]|1[18]))',
     '619' => '(?:(?:02(?:8[0235-9]|9[25])|1(?:[12]95|393)))',
-    '620' => '(?:(?:850[1-7]|149[23]))',
+    '620' => '(?:(?:850[1-8]|149[23]))',
     '621' => '(?:8(?:5(?:[58]5|01)|686))',
     '622' => '(?:(?:0292|8651))',
     '623' => '(?:85(?:01|88))',
@@ -758,7 +758,7 @@ our %ZIP_TABLE = (
     '799' => '(?:(?:1(?:5(?:8[128]|9[2-68])|39[2-5]|198|692)|2(?:49[2356]|29[2-4]|19[25]|39[23]|69[26])|0(?:19[2-7]|49[235-8])|3(?:19[2-6]|79[23]|292)))',
     '800' => '(?:(?:0(?:2(?:9[3-8]|8[1-48])|39[2-6])|8(?:5(?:10|85|5[05])|6(?:11|86|0[13]))))',
     '801' => '(?:8(?:5(?:85|5[05]|0[237]|1[01])|601))',
-    '802' => '(?:8(?:5(?:8[015]|3[34]|2[124]|1[0-25]|6[067]|[45][05]|0[18]|7[017])|6(?:42|51|77|86|0[14])))',
+    '802' => '(?:8(?:5(?:8[015]|3[34]|2[124]|1[0-25]|6[067]|[45][05]|0[18]|7[017])|6(?:42|51|77|86|0[14])|701))',
     '803' => '(?:8(?:5(?:20|43|3[0-35]|6[17]|5[058]|8[068]|1[0-357]|0[1458])|6(?:02|30|86|6[06])|787))',
     '804' => '(?:8(?:5(?:[12]0|77|88|0[135]|3[89]|5[058])|601))',
     '805' => '(?:8(?:5(?:[58]5|3[013-689]|2[0178]|0[1357-9]|1[02-468])|6(?:06|25)))',
@@ -766,9 +766,9 @@ our %ZIP_TABLE = (
     '807' => '(?:(?:85(?:01|8[568]|5[56])|019[28]|1392))',
     '808' => '(?:(?:8(?:5(?:02|1[045]|5[058]|8[58])|606)|0196))',
     '809' => '(?:8501)',
-    '810' => '(?:8(?:5(?:3[0-357-9]|7[0-2578]|1[1-9]|2[0-578]|0[1-46-9]|5[135-7]|8[13-57-9]|6[0135-8]|4[0-6])|6(?:5[0-7]|4[28]|6[02-79]|3[01346-8]|1[0179]|8[35689]|0[13-9]|2[0-2579]|7[035-8])|7(?:98|2[0-257]|0[17]|3[14]|1[06-8])))',
+    '810' => '(?:8(?:5(?:3[0-357-9]|7[0-2578]|1[1-9]|5[135-8]|2[0-578]|0[1-46-9]|8[13-57-9]|6[0135-8]|4[0-6])|6(?:5[0-7]|4[28]|6[02-79]|3[01346-8]|1[0179]|8[35689]|0[13-9]|2[0-2579]|7[035-8])|7(?:98|2[0-257]|0[17]|3[14]|1[06-8])))',
     '811' => '(?:(?:2(?:29[2-578]|49[256]|19[23]|39[28]|592)|3(?:19[23578]|29[3568]|492|598)|4(?:19[2358]|39[23]|292)|1(?:39[2-57]|29[28])|0(?:19[2356]|295)|5192))',
-    '812' => '(?:(?:8(?:6(?:6[023689]|1[13-578]|4[0-24-68]|2[024-689]|5[0-689]|0[1-35689]|7[0-246-9]|3[0-36-9]|8[013-9])|5(?:5[0-35-79]|2\d|7[03-7]|4[1-8]|3[0-36-9]|0[13-57-9]|1[0-5]|8[0-24-9]|6[024-8])|7(?:1[0-278]|9[24]|0[235-9]))|95(?:11|20|8[89]|0[235]|5[12])))',
+    '812' => '(?:(?:8(?:6(?:6[023689]|1[13-578]|4[0-24-68]|2[024-689]|5[0-689]|0[1-35689]|7[0-246-9]|3[0-36-9]|8[013-9])|5(?:5[0-35-79]|2\d|7[03-7]|4[1-8]|3[0-36-9]|0[13-57-9]|1[0-5]|8[0-24-9]|6[024-8])|7(?:1[0-278]|0[35-9]|9[24]))|95(?:11|20|8[89]|0[235]|5[12])))',
     '813' => '(?:8(?:5(?:29|33|68|1[39]|7[78]|0[13]|8[58])|6(?:2[36]|8[01])))',
     '814' => '(?:(?:8(?:5(?:77|0[135]|2[0-25]|5[03-68]|6[57]|8[589]|1[0-2])|6(?:02|51)|798)|01(?:80|9[238])))',
     '815' => '(?:8(?:5(?:11|33|88|4[06]|0[13]|2[09]|5[05])|6(?:[68]6|01)))',
